@@ -223,16 +223,16 @@ class RequestBuild(Resource):
     @check_token
     def post(self):
         json_data = request.get_json(force=True)
-        if not isinstance(json_data, list):
+        if not isinstance(json_data, dict):
             return (
                 {
                     "tuxbuild_status": "error",
-                    "status_message": "invalid input: expected list of build dictionaries",
+                    "status_message": "invalid input: expected dict of builds",
                 },
                 400,
             )
         result = []
-        for item in json_data:
+        for item in json_data["builds"]:
             try:
                 Build.validate(item)
             except Exception as e:
@@ -240,7 +240,7 @@ class RequestBuild(Resource):
                     {"tuxbuild_status": "Invalid Request", "status_message": str(e)},
                     400,
                 )
-        for item in json_data:
+        for item in json_data["builds"]:
             result.append(Build.put(None, item, request.url_root))
         return result
 
@@ -310,7 +310,7 @@ class TuxAPIBuilds(Resource):
     @check_token
     def post(self):
         json_data = request.get_json(force=True)
-        if not isinstance(json_data, list):
+        if not isinstance(json_data, dict):
             return (
                 {
                     "tuxbuild_status": "error",
@@ -319,7 +319,7 @@ class TuxAPIBuilds(Resource):
                 400,
             )
         result = []
-        for item in json_data:
+        for item in json_data["builds"]:
             try:
                 Build.validate(item)
             except Exception as e:
@@ -327,7 +327,7 @@ class TuxAPIBuilds(Resource):
                     {"tuxbuild_status": "Invalid Request", "status_message": str(e)},
                     400,
                 )
-        for item in json_data:
+        for item in json_data["builds"]:
             result.append(Build.put(None, item, request.url_root))
         return result
 
