@@ -453,7 +453,10 @@ class TestBuild:
         build_attrs[attr] = value
         with pytest.raises(AssertionError) as assertion:
             tuxsuite.build.Build(**build_attrs)
-        assert attr in str(assertion)
+        if attr == "target_arch":
+            assert "target-arch" in str(assertion)
+        else:
+            assert attr in str(assertion)
 
     def test_validates_git_url(self, build_attrs):
         build_attrs["git_repo"] = "ssh://foo.com:bar.git"
