@@ -3,16 +3,7 @@
 import sys
 import json
 import pytest
-from tuxsuite.cli.argparse import setup_parser
-from tuxsuite.cli.requests import headers
-from tuxsuite.cli.test import (
-    handle_get,
-    handle_list,
-    handle_logs,
-    handle_results,
-    handle_wait,
-    handle_submit,
-)
+import tuxsuite
 
 
 @pytest.fixture
@@ -191,12 +182,10 @@ def test_test_handle_get(mocker, test_json, config, response, monkeypatch):
     monkeypatch.setattr(
         sys, "argv", ["tuxsuite", "test", "get", "1t2giU7PHbVdarV0ZFIohd0PvFb"]
     )
-    options = setup_parser(config.group, config.project).parse_args()
     response.status_code = 200
     response._content = test_json
     get_req = mocker.patch("requests.get", return_value=response)
-    result = handle_get(options, config)
-    assert result == 0
+    tuxsuite.cli.main()
     assert get_req.call_count == 1
 
     # Test json out
@@ -205,19 +194,17 @@ def test_test_handle_get(mocker, test_json, config, response, monkeypatch):
         "argv",
         ["tuxsuite", "test", "get", "1t2giU7PHbVdarV0ZFIohd0PvFb", "--json"],
     )
-    options = setup_parser(config.group, config.project).parse_args()
     response.status_code = 200
     response._content = test_json
     get_req = mocker.patch("requests.get", return_value=response)
-    result = handle_get(options, config)
-    assert result == 0
+    tuxsuite.cli.main()
     assert get_req.call_count == 1
 
     # Test failure case when the response is not 200
     response.status_code = 500
     get_req = mocker.patch("requests.get", return_value=response)
     with pytest.raises(NotImplementedError):
-        result = handle_get(options, config)
+        tuxsuite.cli.main()
     assert get_req.call_count == 1
 
 
@@ -225,12 +212,10 @@ def test_test_handle_get_error(mocker, test_error_json, config, response, monkey
     monkeypatch.setattr(
         sys, "argv", ["tuxsuite", "test", "get", "1t2giU7PHbVdarV0ZFIohd0PvFb"]
     )
-    options = setup_parser(config.group, config.project).parse_args()
     response.status_code = 200
     response._content = test_error_json
     get_req = mocker.patch("requests.get", return_value=response)
-    result = handle_get(options, config)
-    assert result == 0
+    tuxsuite.cli.main()
     assert get_req.call_count == 1
 
 
@@ -238,34 +223,30 @@ def test_test_handle_get_fail(mocker, test_fail_json, config, response, monkeypa
     monkeypatch.setattr(
         sys, "argv", ["tuxsuite", "test", "get", "1t2giU7PHbVdarV0ZFIohd0PvFb"]
     )
-    options = setup_parser(config.group, config.project).parse_args()
     response.status_code = 200
     response._content = test_fail_json
     get_req = mocker.patch("requests.get", return_value=response)
-    result = handle_get(options, config)
-    assert result == 0
+    tuxsuite.cli.main()
     assert get_req.call_count == 1
 
 
 def test_test_handle_list(mocker, test_list_json, config, response, monkeypatch):
     monkeypatch.setattr(sys, "argv", ["tuxsuite", "test", "list"])
     monkeypatch.setattr("sys.stdout.isatty", lambda: True)
-    options = setup_parser(config.group, config.project).parse_args()
     response.status_code = 200
     response._content = test_list_json
     list_req = mocker.patch("requests.get", return_value=response)
     with pytest.raises(SystemExit) as exit:
-        handle_list(options, config)
+        tuxsuite.cli.main()
     assert exit.value.code == 0
     assert list_req.call_count == 2
 
     # Test json out
     monkeypatch.setattr(sys, "argv", ["tuxsuite", "test", "list", "--json"])
-    options = setup_parser(config.group, config.project).parse_args()
     response.status_code = 200
     response._content = test_list_json
     list_req = mocker.patch("requests.get", return_value=response)
-    handle_list(options, config)
+    tuxsuite.cli.main()
     assert exit.value.code == 0
     assert list_req.call_count == 1
 
@@ -273,7 +254,7 @@ def test_test_handle_list(mocker, test_list_json, config, response, monkeypatch)
     response.status_code = 500
     list_req = mocker.patch("requests.get", return_value=response)
     with pytest.raises(NotImplementedError):
-        handle_list(options, config)
+        tuxsuite.cli.main()
     assert list_req.call_count == 1
 
 
@@ -281,28 +262,34 @@ def test_test_handle_logs(mocker, config, response, monkeypatch):
     monkeypatch.setattr(
         sys, "argv", ["tuxsuite", "test", "logs", "1yiYkYq26HbT5i304xElM5Czj2d"]
     )
-    options = setup_parser(config.group, config.project).parse_args()
     response.status_code = 200
     response._content = b"""- {"dt": "2021-09-27T09:58:08.499180", "lvl": "info", "msg": "msg-1"}
 - {"dt": "2021-09-27T09:58:08.499454", "lvl": "info", "msg": "msg-2"}
 - {"dt": "2021-09-27T09:58:08.500845", "lvl": "debug", "msg": "msg-3"}
 """
     logs_req = mocker.patch("requests.get", return_value=response)
-    result = handle_logs(options, config)
-    assert result == 0
+    tuxsuite.cli.main()
     assert logs_req.call_count == 1
 
     # test raw output
-    options.raw = True
-    result = handle_logs(options, config)
-    assert result == 0
-    assert logs_req.call_count == 2
+    mocker.resetall()
+    monkeypatch.setattr(
+        sys,
+        "argv",
+        ["tuxsuite", "test", "logs", "1yiYkYq26HbT5i304xElM5Czj2d", "--raw"],
+    )
+    response.status_code = 200
+    response._content = b""
+    tuxsuite.cli.main()
+    logs_req = mocker.patch("requests.get", return_value=response)
+    tuxsuite.cli.main()
+    assert logs_req.call_count == 1
 
     # Test failure case when the response is not 200
     response.status_code = 500
     logs_req = mocker.patch("requests.get", return_value=response)
     with pytest.raises(NotImplementedError):
-        result = handle_logs(options, config)
+        tuxsuite.cli.main()
     assert logs_req.call_count == 1
 
 
@@ -310,84 +297,46 @@ def test_test_handle_results(mocker, config, result_json, response, monkeypatch)
     monkeypatch.setattr(
         sys, "argv", ["tuxsuite", "test", "results", "1yiYkYq26HbT5i304xElM5Czj2d"]
     )
-    options = setup_parser(config.group, config.project).parse_args()
     response.status_code = 200
     response._content = result_json
     logs_req = mocker.patch("requests.get", return_value=response)
-    result = handle_results(options, config)
-    assert result == 0
+    tuxsuite.cli.main()
     assert logs_req.call_count == 1
 
     # test raw output
-    options.raw = True
-    result = handle_results(options, config)
-    assert result == 0
-    assert logs_req.call_count == 2
+    mocker.resetall()
+    monkeypatch.setattr(
+        sys,
+        "argv",
+        ["tuxsuite", "test", "results", "1yiYkYq26HbT5i304xElM5Czj2d", "--raw"],
+    )
+    response._content = b""
+    tuxsuite.cli.main()
+    results_req = mocker.patch("requests.get", return_value=response)
+    tuxsuite.cli.main()
+    assert results_req.call_count == 1
 
     # Test failure case when the response is not 200
     response.status_code = 500
-    logs_req = mocker.patch("requests.get", return_value=response)
+    requests_req = mocker.patch("requests.get", return_value=response)
     with pytest.raises(NotImplementedError):
-        result = handle_results(options, config)
-    assert logs_req.call_count == 1
+        tuxsuite.cli.main()
+    assert requests_req.call_count == 1
 
 
 def test_test_handle_wait(mocker, test_json, config, response, monkeypatch):
     monkeypatch.setattr(
         sys, "argv", ["tuxsuite", "test", "wait", "1t2giU7PHbVdarV0ZFIohd0PvFb"]
     )
-    options = setup_parser(config.group, config.project).parse_args()
     response.status_code = 200
     response._content = test_json
     wait_req = mocker.patch("requests.get", return_value=response)
-    result = handle_wait(options, config)
-    assert result == 0
+    tuxsuite.cli.main()
     assert wait_req.call_count == 1
 
     # Test failure case when the response is not 200
     response.status_code = 500
     wait_req = mocker.patch("requests.get", return_value=response)
     with pytest.raises(NotImplementedError):
-        result = handle_wait(options, config)
+        tuxsuite.cli.main()
     assert wait_req.call_count == 1
-
-
-def test_test_handle_submit(mocker, config, response, monkeypatch):
-    monkeypatch.setattr(
-        sys,
-        "argv",
-        [
-            "tuxsuite",
-            "test",
-            "submit",
-            "--device",
-            "qemu-i386",
-            "--kernel",
-            "http://example.com/image/",
-            "--tests",
-            "ltp-smoke",
-        ],
-    )
-    options = setup_parser(config.group, config.project).parse_args()
-    response.status_code = 201
-    response._content = b'{"a": "b"}'
-    post_req = mocker.patch("requests.post", return_value=response)
-    mocker.patch("tuxsuite.cli.models.Test.new", return_value={"a": "b"})
-    handle_submit(options, config)
-    post_req.assert_called_with(
-        f"{config.tuxapi_url}/v1/groups/{config.group}/projects/{config.project}/tests",
-        headers=headers(config),
-        json={
-            "device": "qemu-i386",
-            "kernel": "http://example.com/image/",
-            "tests": ["ltp-smoke"],
-        },
-    )
-    assert post_req.call_count == 1
-
-    # Test failure case when the response is not 201
-    response.status_code = 500
-    post_req = mocker.patch("requests.post", return_value=response)
-    with pytest.raises(NotImplementedError):
-        handle_submit(options, config)
-    assert post_req.call_count == 1
