@@ -1,10 +1,22 @@
 # -*- coding: utf-8 -*-
 
+import argparse
+import tuxsuite.exceptions
 import tuxsuite.cli.colors as colors
 import tuxsuite.cli.icons as icons
+from tuxsuite.cli.common import common_options
 from tuxsuite.cli.models import Build
 from tuxsuite.cli.requests import apiurl, get
-from tuxsuite.cli.utils import LIMIT, datediff, fetch_next
+from tuxsuite.cli.utils import (
+    LIMIT,
+    datediff,
+    fetch_next,
+    key_value,
+    wait_for_object,
+    error,
+    format_result,
+    show_log,
+)
 
 import json
 import requests
@@ -12,7 +24,21 @@ import sys
 import time
 
 
-def handle_config(options, config):
+def get_make_targets_vars(targets):
+    target_list = []
+    make_variables = {}
+    if targets:
+        key_values = [arg for arg in targets if "=" in arg]
+        for kv in key_values:
+            if kv.count("=") > 1:
+                sys.stderr.write(f"Error: invalid KEY=VALUE: {kv}")
+                sys.exit(1)
+            make_variables = dict((arg.split("=") for arg in key_values))
+        target_list = [arg for arg in targets if "=" not in arg]
+    return (target_list, make_variables)
+
+
+def handle_config(options, _, config):
     ret = get(
         config,
         f"/v1/groups/{config.group}/projects/{config.project}/builds/{options.uid}",
@@ -28,7 +54,7 @@ def handle_config(options, config):
     return 0
 
 
-def handle_get(options, config):
+def handle_get(options, _, config):
     ret = get(
         config,
         f"/v1/groups/{config.group}/projects/{config.project}/builds/{options.uid}",
@@ -89,7 +115,7 @@ def handle_get(options, config):
     return 0
 
 
-def handle_list(options, config):
+def handle_list(options, _, config):
     url = f"/v1/groups/{config.group}/projects/{config.project}/builds"
     ret = get(config, url)
     if ret.status_code != 200:
@@ -133,7 +159,7 @@ def handle_list(options, config):
     return 0
 
 
-def handle_logs(options, config):
+def handle_logs(options, _, config):
     ret = get(
         config,
         f"/v1/groups/{config.group}/projects/{config.project}/builds/{options.uid}",
@@ -152,7 +178,7 @@ def handle_logs(options, config):
     return 0
 
 
-def handle_wait(options, config):
+def handle_wait(options, _, config):
     previous_state = None
     while True:
         ret = get(
@@ -222,15 +248,169 @@ def handle_wait(options, config):
     return 0
 
 
+def handle_submit(cmdargs, _, config):
+    if cmdargs.git_head:
+        try:
+            cmdargs.git_repo, cmdargs.git_sha = tuxsuite.gitutils.get_git_head()
+        except Exception as e:
+            error(e)
+
+    targets = ["config", "debugkernel", "dtbs", "kernel", "modules", "xipkernel"]
+    make_variables = {}
+    if cmdargs.targets[0]:
+        target_list, make_vars = get_make_targets_vars(cmdargs.targets[0])
+        targets = target_list
+        make_variables = make_vars
+
+    environment = {}
+    for e in cmdargs.environment:
+        environment[e[0][0]] = e[0][1]
+
+    try:
+        build = tuxsuite.Build(
+            git_repo=cmdargs.git_repo,
+            git_ref=cmdargs.git_ref,
+            git_sha=cmdargs.git_sha,
+            target_arch=cmdargs.target_arch,
+            kconfig=cmdargs.kconfig,
+            toolchain=cmdargs.toolchain,
+            environment=environment,
+            targets=targets,
+            make_variables=make_variables,
+            kernel_image=cmdargs.kernel_image,
+            patch_series=cmdargs.patch_series,
+            image_sha=cmdargs.image_sha,
+            build_name=cmdargs.build_name,
+            no_cache=cmdargs.no_cache,
+        )
+
+    except (AssertionError, tuxsuite.exceptions.TuxSuiteError) as e:
+        error(e)
+    print(
+        "Building Linux Kernel {} at {}".format(
+            build.git_repo, build.git_ref or build.git_sha
+        )
+    )
+    try:
+        build.build()
+        print("uid: {}".format(build.uid))
+    except tuxsuite.exceptions.BadRequest as e:
+        raise (argparse.ArgumentTypeError(str(e)))
+
+    build_result = True
+
+    if cmdargs.no_wait:
+        format_result(build.status)
+    else:
+        build_result = wait_for_object(build)
+
+    if cmdargs.json_out:
+        cmdargs.json_out.write(json.dumps(build.status, sort_keys=True, indent=4))
+    if cmdargs.download:
+        tuxsuite.download.download(build, cmdargs.output_dir)
+    if cmdargs.show_logs:
+        show_log(build, cmdargs.download, cmdargs.output_dir)
+    if cmdargs.quiet:
+        print(build.build_data)
+
+    if not build_result:
+        sys.exit(1)
+
+
 handlers = {
     "config": handle_config,
     "get": handle_get,
     "list": handle_list,
     "logs": handle_logs,
     "wait": handle_wait,
+    "submit": handle_submit,
 }
 
 
+def build_cmd_options(sp):
+    toolchains = [
+        "gcc-8",
+        "gcc-9",
+        "gcc-10",
+        "gcc-11",
+        "gcc-12",
+        "clang-10",
+        "clang-11",
+        "clang-12",
+        "clang-13",
+        "clang-14",
+        "clang-nightly",
+        "clang-android",
+        "rust",
+        "rustgcc",
+        "rustclang",
+        "rustllvm",
+    ]
+
+    sp.add_argument(
+        "--build-name",
+        help="User defined string to identify the build",
+        type=str,
+    )
+    sp.add_argument(
+        "targets",
+        nargs="*",
+        help="""Targets to build. If no TARGETs are specified, tuxsuite will
+        build config + debugkernel + dtbs + kernel + modules + xipkernel.""",
+        type=str,
+        action="append",
+    )
+    sp.add_argument(
+        "make-variables",
+        nargs="*",
+        help="Make variables to use. Format: KEY=VALUE",
+        default=[],
+        type=key_value,
+        action="append",
+    )
+    sp.add_argument(
+        "-e",
+        "--environment",
+        type=key_value,
+        nargs="*",
+        help="Set environment variables for the build. Format: KEY=VALUE",
+        default=[],
+        action="append",
+    )
+    sp.add_argument(
+        "-q",
+        "--quiet",
+        default=False,
+        action="store_true",
+        help="Supress all informational output; prints only the download URL for the build",
+    )
+    sp.add_argument(
+        "--toolchain",
+        help=f"Toolchain [{'|'.join(toolchains)}]",
+    )
+    sp.add_argument(
+        "--kconfig",
+        nargs="?",
+        help="Kernel kconfig arguments (may be specified multiple times)",
+        type=str,
+        default=[],
+        action="append",
+    )
+    sp.add_argument(
+        "--kernel-image",
+        help="Specify custom kernel image that you wish to build",
+    )
+    sp.add_argument(
+        "--target-arch",
+        help="Target architecture [arc|arm|arm64|hexagon|i386|mips|parisc|powerpc|riscv|s390|sh|sparc|x86_64]",
+    )
+    sp.add_argument(
+        "--image-sha",
+        default=None,
+        help="Pin the container image sha (64 hexadecimal digits)",
+    )
+
+
 def setup_parser(parser):
     # "build config <uid>"
     t = parser.add_parser("config")
@@ -250,6 +430,13 @@ def setup_parser(parser):
     t = parser.add_parser("logs")
     t.add_argument("uid")
 
+    # "build submit"
+    t = parser.add_parser("submit")
+    build_cmd_options(t)
+    common_options(t)
+
     # "build wait <uid>"
     p = parser.add_parser("wait")
     p.add_argument("uid")
+
+    return sorted(parser._name_parser_map.keys())
